.. _scripts:

Command line tools
==================

The ``gammapy/scripts`` folder contains command line tools
that are also installed in the ``bin`` directory if you install Gammapy
and are thus available to you if that is on your ``$PATH``. 

TODO: explain better how to find out where the scripts were installed,
i.e. what the user should add to their ``$PATH``.

.. note:: For now the full list of scripts is only available here:
   https://github.com/gammapy/gammapy/tree/master/scripts
   
   We plan to integrate that into the online Sphinx docs ...
   please help if you know how to do this:
   https://github.com/gammapy/gammapy/issues/24

Here's an example of a script listed by hand ... this should be auto-generated
by ``build_sphinx``:

.. toctree::
  :maxdepth: 1

  gammapy-info
